@@ -13,14 +13,14 @@ except:
 
 discovery = os.environ.get('discovery_url', "https://discovery.data.storemesh.com")
 
-_base_discovery_api = "https://api.discovery.data.storemesh.com"
-_internal_base_discovery_api = "http://backend:8000"
+_base_discovery_api = os.environ.get('BASE_DISCOVERY_API', "https://api.discovery.data.storemesh.com")
+_internal_base_discovery_api = os.environ.get('INTERNAL_BASE_DISCOVERY_API',"http://discovery-backend:8000")
 
 _external_api_minio = os.environ.get('external_api_minio',"")
 _internal_api_minio = os.environ.get('internal_api_minio',"")
 
 _base_minio_url=os.environ.get('base_minio_url')
-bucket_name = 'dataplatform'
+bucket_name = os.environ.get('bucketname', 'dataplatform')
 
 class Base:
     def __init__(self, token=None):
@@ -78,6 +78,8 @@ class Base:
             }
         }
         
+        print("Init DataNode sucessful!")
+        
     def _replace_minio_api(self, url):
         return url.replace('https', 'http').replace(_external_api_minio, _internal_api_minio)
     
