@@ -12,14 +12,12 @@ def append_slash(txt):
     return txt
 
 class DataNode(DatasetManager):
-    def write(self, ddf=None, df=None, directory=None, name=None, description="", replace=None, profiling=False, **kwargs):
-        if (ddf is None) and (df is None):
-            raise Exception(f"Please input ddf(dask dataframe) or df(pandas dataframe), got {type(ddf) or type(df)}")
-        if (type(ddf) != dd.DataFrame) and (type(df) != pd.DataFrame):
-            raise Exception("Invalid type expect ddf(dask dataframe) or df(pandas dataframe)")
+    def write(self, df=None, directory=None, name=None, description="", replace=None, profiling=False, **kwargs):
+        if type(df) not in [pd.DataFrame, dd.DataFrame]:
+            raise Exception(f"Invalid type expect ddf(dask dataframe) or df(pandas dataframe), Please input `df=`, but got {type(df)}")
         if name == None or type(name) != str:
             raise Exception(f"Please input data name, but got {type(name)}")
-        if description=="":
+        if description=="" and type(description)!=str:
             description = f"data {name}"
             
         name = f'{name}.parquet'
@@ -37,8 +35,7 @@ class DataNode(DatasetManager):
         if _res.status_code != 201:
             raise Exception(f"can not create directory in discovery {_res.json()}")
         meta = _res.json()
-        _df_ddf = ddf if type(ddf) == dd.DataFrame else df
-        _df_ddf.to_parquet(f"s3://{bucket_name}/{meta['key']}",
+        df.to_parquet(f"s3://{bucket_name}/{meta['key']}",
             storage_options=self._storage_options,
             **kwargs
         )
@@ -57,7 +54,7 @@ class DataNode(DatasetManager):
         return {
             'sucess': True,
             'file_id': meta['id'],
-            'path': meta['key']
+            'path': meta['path']
         }
     
     def get_file(self, file_id=None):
@@ -66,13 +63,16 @@ class DataNode(DatasetManager):
             txt = _res.json() if _res.status_code < 500 else " "
             raise Exception(f"Some thing wrong, {txt}")
         meta = _res.json()
-        
         try:
             response = self.client.get_object(bucket_name=bucket_name, object_name=meta['s3_key'])
         except Exception as e:
             raise e
         else:
-            return io.BytesIO(response.data)
+            meta.update({
+                'owner': meta['owner']['user']
+            })
+            meta = {key: value for key,value in meta.items() if key in ['owner', 'name', 'description', 'path', 'directory', 'human_size']}
+            return meta, io.BytesIO(response.data)
         
     
     def read_ddf(self, file_id=None):
